==> neo4j-fulltext-index-3.5.27-sources.jar: org/neo4j/kernel/api/impl/fulltext/analyzer/providers/Thai.java <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.kernel.api.impl.fulltext.analyzer.providers;

import org.apache.lucene.analysis.Analyzer;
import org.apache.lucene.analysis.th.ThaiAnalyzer;

import org.neo4j.graphdb.index.fulltext.AnalyzerProvider;
import org.neo4j.helpers.Service;

@Service.Implementation( AnalyzerProvider.class )
public class Thai extends AnalyzerProvider
{
    public Thai()
    {
        super( "thai" );
    }

    @Override
    public Analyzer createAnalyzer()
    {
        return new ThaiAnalyzer();
    }

    @Override
    public String description()
    {
        return "Thai analyzer with stop word filtering. It relies on the Java built-in localization support for the Thai locale in order to break apart " +
                "and tokenize words, which might not be available depending on Java version and JRE vendor.";
    }
}

==> neo4j-fulltext-index-4.2.1-sources.jar: org/neo4j/kernel/api/impl/fulltext/analyzer/providers/Thai.java <==
/*
 * Copyright (c) 2002-2020 "Neo4j,"
 * Neo4j Sweden AB [http://neo4j.com]
 *
 * This file is part of Neo4j.
 *
 * Neo4j is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
package org.neo4j.kernel.api.impl.fulltext.analyzer.providers;

import org.apache.lucene.analysis.Analyzer;
import org.apache.lucene.analysis.th.ThaiAnalyzer;

import org.neo4j.annotations.service.ServiceProvider;
import org.neo4j.graphdb.schema.AnalyzerProvider;

@ServiceProvider
public class Thai extends AnalyzerProvider
{
    public Thai()
    {
        super( "thai" );
    }

    @Override
    public Analyzer createAnalyzer()
    {
        return new ThaiAnalyzer();
    }

    @Override
    public String description()
    {
        return "Thai analyzer with stop word filtering. It relies on the Java built-in localization support for the Thai locale in order to break apart " +
                "and tokenize words, which might not be available depending on Java version and JRE vendor.";
    }
}
